'use strict';

var jsUtils = require('js-utils');
var fs = require('fs');

/**
 * @function
 * @async
 * @param path
 * @param [mode]
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_access_path_mode_callback}
 */
var access = jsUtils.toAsync(fs.access);

/**
 * @function
 * @async
 * @param file
 * @param data
 * @param [options]
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_appendfile_file_data_options_callback}
 */
var appendFile = jsUtils.toAsync(fs.appendFile);

/**
 * @function
 * @async
 * @param path
 * @param mode
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_chmod_path_mode_callback}
 */
var chmod = jsUtils.toAsync(fs.chmod);

/**
 * @function
 * @async
 * @param path
 * @param uid
 * @param gid
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_chown_path_uid_gid_callback}
 */
var chown = jsUtils.toAsync(fs.chown);

/**
 * @function
 * @async
 * @param fd
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_close_fd_callback}
 */
var close = jsUtils.toAsync(fs.close);

/**
 * @function
 * @async
 * @param path
 * @param mode
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_fchmod_fd_mode_callback}
 */
var fchmod = jsUtils.toAsync(fs.fchmod);

/**
 * @function
 * @async
 * @param fd
 * @param mode
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_fchown_fd_uid_gid_callback}
 */
var fchown = jsUtils.toAsync(fs.fchown);

/**
 * @function
 * @async
 * @param fd
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_fstat_fd_callback}
 */
var fstat = jsUtils.toAsync(fs.fstat);

/**
 * @function
 * @async
 * @param fd
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_fsync_fd_callback}
 */
var fsync = jsUtils.toAsync(fs.fsync);

/**
 * @function
 * @async
 * @param fd
 * @param len
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_ftruncate_fd_len_callback}
 */
var ftruncate = jsUtils.toAsync(fs.ftruncate);

/**
 * @function
 * @async
 * @param fd
 * @param atime
 * @param mtime
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_futimes_fd_atime_mtime_callback}
 */
var futimes = jsUtils.toAsync(fs.futimes);

/**
 * @function
 * @async
 * @param path
 * @param mode
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_lchmod_path_mode_callback}
 */
var lchmod = jsUtils.toAsync(fs.lchmod);

/**
 * @function
 * @async
 * @param path
 * @param uid
 * @param gid
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_lchown_path_uid_gid_callback}
 */
var lchown = jsUtils.toAsync(fs.lchown);

/**
 * @function
 * @async
 * @param srcPath
 * @param destPath
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_link_srcpath_dstpath_callback}
 */
var link = jsUtils.toAsync(fs.link);

/**
 * @function
 * @async
 * @param path
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_lstat_path_callback}
 */
var lstat = jsUtils.toAsync(fs.lstat);

/**
 * @function
 * @async
 * @param path
 * @param [mode]
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_mkdirsync_path_mode}
 */
var mkdir = jsUtils.toAsync(fs.mkdir);

/**
 * @function
 * @async
 * @param path
 * @param flags
 * @param [mode]
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_open_path_flags_mode_callback}
 */
var open = jsUtils.toAsync(fs.open);

/**
 * @function
 * @async
 * @param fd
 * @param buffer
 * @param offset
 * @param length
 * @param position
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_read_fd_buffer_offset_length_position_callback}
 */
var read = jsUtils.toAsync(fs.read);

/**
 * @function
 * @async
 * @param path
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_readdir_path_callback}
 */
var readdir = jsUtils.toAsync(fs.readdir);

/**
 * @function
 * @async
 * @param file
 * @param [options]
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_readfile_file_options_callback}
 */
var readFile = jsUtils.toAsync(fs.readFile);

/**
 * @function
 * @async
 * @param path
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_readlink_path_callback}
 */
var readlink = jsUtils.toAsync(fs.readlink);

/**
 * @function
 * @async
 * @param path
 * @param [cache]
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_realpath_path_cache_callback}
 */
var realpath = jsUtils.toAsync(fs.realpath);

/**
 * @function
 * @async
 * @param oldPath
 * @param newPath
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_rename_oldpath_newpath_callback}
 */
var rename = jsUtils.toAsync(fs.rename);

/**
 * @function
 * @async
 * @param path
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_rmdir_path_callback}
 */
var rmdir = jsUtils.toAsync(fs.rmdir);

/**
 * @function
 * @async
 * @param path
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_stat_path_callback}
 */
var stat = jsUtils.toAsync(fs.stat);

/**
 * @function
 * @async
 * @param target
 * @param path
 * @param [type]
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_symlink_target_path_type_callback}
 */
var symlink = jsUtils.toAsync(fs.symlink);

/**
 * @function
 * @async
 * @param path
 * @param len
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_truncate_path_len_callback}
 */
var truncate = jsUtils.toAsync(fs.truncate);

/**
 * @function
 * @async
 * @param path
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_unlink_path_callback}
 */
var unlink = jsUtils.toAsync(fs.unlink);

/**
 * @function
 * @async
 * @param path
 * @param atime
 * @param mtime
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_utimes_path_atime_mtime_callback}
 */
var utimes = jsUtils.toAsync(fs.utimes);

/**
 * @function
 * @async
 * @param fd
 * @param buffer
 * @param offset
 * @param length
 * @param [position]
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_write_fd_buffer_offset_length_position_callback}
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_write_fd_data_position_encoding_callback}
 */
var write = jsUtils.toAsync(fs.write);

/**
 * @function
 * @async
 * @param file
 * @param data
 * @param [options]
 * @see {@link https://nodejs.org/api/fs.html#fs_fs_writefile_file_data_options_callback}
 */
var writeFile = jsUtils.toAsync(fs.writeFile);

exports.access = access;
exports.appendFile = appendFile;
exports.chmod = chmod;
exports.chown = chown;
exports.close = close;
exports.fchmod = fchmod;
exports.fchown = fchown;
exports.fstat = fstat;
exports.fsync = fsync;
exports.ftruncate = ftruncate;
exports.futimes = futimes;
exports.lchmod = lchmod;
exports.lchown = lchown;
exports.link = link;
exports.lstat = lstat;
exports.mkdir = mkdir;
exports.open = open;
exports.read = read;
exports.readdir = readdir;
exports.readFile = readFile;
exports.readlink = readlink;
exports.realpath = realpath;
exports.rename = rename;
exports.rmdir = rmdir;
exports.stat = stat;
exports.symlink = symlink;
exports.truncate = truncate;
exports.unlink = unlink;
exports.utimes = utimes;
exports.write = write;
exports.writeFile = writeFile;
exports.F_OK = fs.F_OK;
exports.R_OK = fs.R_OK;
exports.W_OK = fs.W_OK;
exports.X_OK = fs.X_OK;
exports.FSWatcher = fs.FSWatcher;
exports.ReadStream = fs.ReadStream;
exports.Stats = fs.Stats;
exports.WriteStream = fs.WriteStream;
exports.createReadStream = fs.createReadStream;
exports.createWriteStream = fs.createWriteStream;
exports.unwatchFile = fs.unwatchFile;
exports.watch = fs.watch;
exports.watchFile = fs.watchFile;
//# sourceMappingURL=js-utils-fs.js.map
